@@ -41,12 +41,20 @@ class mysql_source(object):
             The method check if the mysql configuration is compatible with the replica requirements.
             If all the configuration requirements are met then the return value is True.
             Otherwise is false.
-            The parameters checked are
-            log_bin - ON if the binary log is enabled
+            The parameters checked are:
+            log_bin - ON if the binary log is enabled if we are on a vanilla mysql
             binlog_format - must be ROW , otherwise the replica won't get the data
             binlog_row_image - must be FULL, otherwise the row image will be incomplete
 
+            The method checks the function AURORA_VERSION() and if the query doesn't error then skips the log_bin parameter check.
         """
+        sql_aurora = """select AURORA_VERSION() ver;"""
+        try:
+            self.cursor_buffered.execute(sql_aurora)
+            skip_log_bin_check = True
+        except:
+            skip_log_bin_check = False
+
         if self.gtid_enable:
             sql_log_bin = """SHOW GLOBAL VARIABLES LIKE 'gtid_mode';"""
             self.cursor_buffered.execute(sql_log_bin)
@@ -90,7 +98,7 @@ class mysql_source(object):
         else:
             binlog_row_image = 'FULL'
 
-        if log_bin.upper() == 'ON' and binlog_format.upper() == 'ROW' and binlog_row_image.upper() == 'FULL':
+        if (log_bin.upper() == 'ON' or skip_log_bin_check) and binlog_format.upper() == 'ROW' and binlog_row_image.upper() == 'FULL':
             self.replica_possible = True
         else:
             self.replica_possible = False
@@ -763,12 +771,15 @@ class mysql_source(object):
                         self.pg_engine.collect_idx_cons(destination_schema,table)
                         self.logger.info("Removing constraints and indices from the destination table  %s.%s" %(destination_schema, table) )
                         self.pg_engine.cleanup_idx_cons(destination_schema,table)
+                        self.logger.info("Truncating the table  %s.%s" %(destination_schema, table) )
                         self.pg_engine.truncate_table(destination_schema,table)
+                        master_status = self.copy_data(schema, table)
                     else:
+                        master_status = self.copy_data(schema, table)
                         table_pkey = self.__create_indices(schema, table)
-                    master_status = self.copy_data(schema, table)
                     self.pg_engine.store_table(destination_schema, table, table_pkey, master_status)
                     if self.keep_existing_schema:
+                        #input("Press Enter to continue...")
                         self.logger.info("Adding constraint and indices to the destination table  %s.%s" %(destination_schema, table) )
                         self.pg_engine.create_idx_cons(destination_schema,table)
                 except:
